@@ -6,6 +6,6 @@ A simple task runner.
 
 from typing import List
 
-from duty.logic import duty
+from duty.decorator import duty
 
 __all__: List[str] = ["duty"]  # noqa: WPS410 (the only __variable__ we use)
